@@ -1,7 +1,7 @@
 import os
 from typing import Any, Dict, List, Optional
 
-import numpy as np  # type: ignore
+import numpy as np
 from OpenGL.GL import (
     GL_BLEND,
     GL_CULL_FACE,
@@ -32,7 +32,7 @@ from OpenGL.GL import (
     glTexImage2D,
     glTexParameterf,
 )
-from PIL import Image  # type: ignore
+from PIL import Image
 
 from payton.math.vector import Vector3D
 from payton.scene.shader import Shader
@@ -184,7 +184,7 @@ class Material:
         img -- Image to load
         particle -- Is this a particle material?
         """
-        img_data = np.fromstring(img.tobytes(), np.uint8)
+        img_data = np.fromstring(img.tobytes(), np.uint8)  # type: ignore
         width, height = img.size
         glPixelStorei(GL_UNPACK_ALIGNMENT, 1)
         if particle:
@@ -203,7 +203,7 @@ class Material:
             mode = GL_RGB
         if img.mode == "P":
             img = img.convert("RGB")
-            img_data = np.fromstring(img.tobytes(), np.uint8)
+            img_data = np.fromstring(img.tobytes(), np.uint8)  # type: ignore
             mode = GL_RGB
         glTexImage2D(
             GL_TEXTURE_2D,
@@ -230,22 +230,14 @@ class Material:
         Keyword argument:
         lit -- Is this a lit material?
         """
-        mode = Shader.LIGHT_COLOR
-
-        if self.display == SOLID:
-            if lit and self.lights:
-                if self._texture is not None:
-                    mode = Shader.LIGHT_TEXTURE
-                else:
-                    mode = Shader.LIGHT_COLOR
-            else:
-                if self._texture is not None:
-                    mode = Shader.NO_LIGHT_TEXTURE
-                else:
-                    mode = Shader.NO_LIGHT_COLOR
+        if self.display == SOLID and lit and self.lights and self._texture is not None:
+            return Shader.LIGHT_TEXTURE
+        elif self.display == SOLID and lit and self.lights:
+            return Shader.LIGHT_COLOR
+        elif self.display == SOLID and self._texture is not None:
+            return Shader.NO_LIGHT_TEXTURE
         else:
-            mode = Shader.NO_LIGHT_COLOR
-        return mode
+            return Shader.NO_LIGHT_COLOR
 
     def render(
         self,
@@ -263,7 +255,7 @@ class Material:
         if not self._initialized:
             self.build()
 
-        _mode = mode if mode else self.material_mode(lit)
+        _mode = mode or self.material_mode(lit)
 
         glEnable(GL_BLEND)
         glDisable(GL_CULL_FACE)
